"""Velixar AI integration for LangChain — retriever and memory."""

from .retriever import VelixarRetriever

__all__ = ["VelixarRetriever", "VelixarMemory"]
__version__ = "0.1.1"


def __getattr__(name):
    if name == "VelixarMemory":
        from .memory import VelixarMemory
        return VelixarMemory
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")
